###############################################################################
#
# This file is provided under a dual license.  When you use or
# distribute this software, you may choose to be licensed under
# version 2 of the GNU General Public License ("GPLv2 License")
# or BSD License.
#
# GPLv2 License
#
# Copyright(C) 2019 MediaTek Inc.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of version 2 of the GNU General Public License as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See http://www.gnu.org/licenses/gpl-2.0.html for more details.
#
# BSD LICENSE
#
# Copyright(C) 2019 MediaTek Inc.
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
#  * Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
#  * Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in
#    the documentation and/or other materials provided with the
#    distribution.
#  * Neither the name of the copyright holder nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#
###############################################################################
###########################################################################
# $RCSfile: Makefile,v $
# $Revision: #4 $
# $Date: 2009/08/13 $
# $Author: brianpc.huang $
# $CCRevision: /main/DTV_X_HQ_int/DTV_X_ATSC/51 $
# $SWAuthor: Felisa Hsiao $
# $MD5HEX: 1476db419289e71bcc068156dea7ae10 $
#
# Description:
#         Makefile to build a "MT-5372" demo board build. The following
#         targets are supported:
#
#             all:           Compiles middleware/public, custom, target and this
#                            directory and creates a final image.
#             mw:            Compiles the middleware/public.
#             custom:        Compiles the custom.
#             target:        Compiles the MT-5372 target.
#             image:         Compiles this directory and creates a final
#                            image.
#             clean:         Cleans the middleware/public, custom, target and this
#                            directory and removes the run image.
#             clean_mw:      Cleans the middleware/public.
#             clean_custom:  Cleans the custom.
#             clean_target:  Cleans the MT-5372 target.
#             clean_image:   Cleans this directory and removes the run image.
#             clean_force:   Forcefully removes all libray and object
#                            directories as well as the run image. A fast way
#                            to perform cleanup.
#
#         The following commands are supported:
#
#             BUILD_CFG=debug
#                 Builds the specified target with symbolic debug info and the
#                 define file "mt5372_demo.def" is read. The run image is named
#                 is named "mt5372_demo_dbg".If BUILD_CFG is not specified then
#                 a non-debug build is created, which does not contain any
#                 symbolic debug information.
#
#             BRDCST_IF=<name>
#                 Allows the specifying of the front-end. The name must must
#                 be the directory name of the front-end, which follows the
#                 mt5372 targets brdcst_if sub-directory. For example,
#                 name may be set to "gen2004" or "5111" etc. In case
#                 BRDCST_IF is not set, "5111philips" is assumed.
#############################################################################

# 
# Set initial values.
#

# Region (shall decalre before other configuration)
export MARKET_REGION            := PA
export MARKET_SHIPPING_REGION   := AU
export WARNING_TO_ERROR         := true
ifeq "$(DAILY_BUILD)" "true"
export JUST_TV                  ?= true
else
export JUST_TV                  ?= false
endif
export SHELL                     =/bin/bash
export CPU_TYPE 				?= ca7

ifeq "$(JUST_TV)" "true"
export SIMPLE_IPTV := false
else
export SIMPLE_IPTV := true
endif

#
# CastTv feature 
#
export C4TV := false

# patial efence
ifndef ENABLE_PARTIAL_EFENCE
    export ENABLE_PARTIAL_EFENCE := false
endif

#
#Valgrind enable
#
ifndef ENABLE_VALGRIND
    export ENABLE_VALGRIND := false
endif

ifeq "$(ENABLE_VALGRIND)" "true"
    export BUILD_CFG := debug
    export SYM_SUPPORT := true
endif

ifndef BOOT_ACCELERATE
BOOT_ACCELERATE :=true
endif

ifeq "$(BOOT_ACCELERATE)" "true"
export ASYNC_INS_KO :=true
export READAHEAD_ONDEMAND :=true
export KERNEL_CONFIG_DIFF += readahead_ko
endif

ifeq "$(BUILD_CFG)" "debug"
export LINUX_TUXERA_NTFS_SUPPORT=false
endif
ifndef LINUX_TUXERA_NTFS_SUPPORT
export LINUX_TUXERA_NTFS_SUPPORT := true
endif

ifneq "$(SIMPLE_IPTV)" "true"
# Viper Just TV and Home cTV (common part)
    # feature
    export 3D_SUPPORT        := false
    export SUPPORT_PIP       := false
	# network features
    export BIVL_SUPPORT      := false
    export IPCC_SUPPORT      := false
    export VUDU_CMPB         := false
    export NETFLIX_CMPB      := false
    export NETFLIX_3D        := false
	export IPV6_SUPPORT      := false
    export CUSTOM_SECURE_SUPPORT := false

    # do not need bluez and libusb library
    export DISABLE_BLUEZ_LIBUSB := true

    # nand flash
    export USE_256MB_NAND    := true
    export USE_256MB_NAND_SUPPORT_PKG_DOWNLOAD := true
 	export EEPTOFLASH        := true

    # trustzone
    export SVP_SUPPORT       := false
    export ENABLE_HCI        := false
	export ENABLE_KEYSTORE   := true
    # check if need to use different eeprom setting for MTK internal use
     ifneq "$(strip $(MTK_SERVER))" ""
	    export MTK_SERVER
	 endif

    # NET App Configuration
    export REBUILD_3RD_PARTY  ?= true

# Viper Just TV and Home cTV (specific part)
    ifeq "$(JUST_TV)" "true"
    # Viper Just TV Only
	    # network features
        export PHOTO_SHARE_SUPPORT   := false
        export PLAY_ANYWHERE_SUPPORT := false
        export SIP_SWKB_SUPPORT      := false
        export RELEASE_3RD_LIB_WIFI  := false

        # NET App Configuration
		export INET_SUPPORT      := true
        export RELEASE_3RD_POLICY = SONY_JUST_TV

    else
    # Viper Home cTV Only
        # NET App Configuration
        export RELEASE_3RD_POLICY = SONY_HOME_CTV
	endif

    export PLAYREADY_2.0_SUPPORT := true
else
# Viper Simple IPTV
    # feature
    export 3D_SUPPORT        := false
    export SUPPORT_PIP       := false
	# network features
    export BIVL_SUPPORT      := true
    export IPCC_SUPPORT      := false
    export VUDU_CMPB         := false
    export NETFLIX_CMPB      := true
    export NETFLIX_3D        := false
	export IPV6_SUPPORT      := true
    export CUSTOM_SECURE_SUPPORT := true
    export B2R_NPTV_SEAMLESS_SUPPORT := true
    # NET App Configuration SONY_IPTV include BIVL
    export RELEASE_3RD_POLICY = SONY_IPTV
    export REBUILD_3RD_PARTY  ?= true
    ifndef MSS_SUPPORT
        export MSS_SUPPORT := true
    endif
    export PLAYREADY_2.0_SUPPORT := false
    #
    # DockUI draw with DFB
    #
    ifndef DOCKUI_DFB
    export DOCKUI_DFB = true
    endif
endif

# 3rd-party application
export BRAND            := Sony
export ODM              := Sony

# India lanaguages rendering
ifndef ICU_SUPPORT
export ICU_SUPPORT := true
endif

ifeq "$(ICU_SUPPORT)" "true"
DEFINES += -DSYS_ICU_LAYOUT_SUPPORT
endif

ifeq "$(DEMO_BOARD)" "true"
export PCB?=m3v1
else
export PCB?=CVT2
endif

ifneq "$(findstring $(PCB),SCT CVT1 CVT2 MVT)" ""
export PANEL_ON_FLASH=true
export AC_DETECT=true
export SELF_DIAG_ENABLE=true
export SELF_DIAG_ON=true
export MANUAL_PANEL_SEL=true
export RUN_ON_SOEM_BOARD=true
else
export PANEL_ON_FLASH=true
export AC_DETECT=true
export SELF_DIAG_ENABLE=true
export SELF_DIAG_ON=false
export MANUAL_PANEL_SEL=false
endif

ifneq "$(findstring $(PCB),SCT CVT1 m3v1)" ""
export BOOT_NOR2NAND_ENABLE 	?= true
else
export BOOT_NOR2NAND_ENABLE 	?= false
endif

export MODEL_DETECT=false
ifndef OLD_PCBA
export OLD_PCBA=false
endif

ifeq "$(ENABLE_EFENCE_DTV_SVC)" "true"
export FAST_BOOT   := false
else
export FAST_BOOT   := true
endif

ifndef MDNSD_SUPPORT
export MDNSD_SUPPORT := false
endif

#For ptp/mtp feature
ifndef MTP_SUPPORT
export MTP_SUPPORT := true
endif

ifndef SKYPE_SUPPORT
export SKYPE_SUPPORT := false
endif

ifndef USE_256MB_NAND
export USE_256MB_NAND := false
endif

#add for audio record
ifndef AUD_DATA_UPLOAD_SUPPORT
export AUD_DATA_UPLOAD_SUPPORT := true
endif

#export DUAL_AUD_DEC_SUPPORT := true

ifndef TRUSTZONE
export TRUSTZONE := true
endif

ifeq "$(TRUSTZONE)" "true"
	ifndef SVP_SUPPORT
		export SVP_SUPPORT := true
	endif
	ifeq "$(JUST_TV)" "false"
	ifndef TVP_SUPPORT
		export TVP_SUPPORT := true
	endif
	endif
    #ifndef WIDEVINE_L1_SUPPORT
     #   export WIDEVINE_L1_SUPPORT := false
    #endif	
else
	export TVP_SUPPORT := false
	export SVP_SUPPORT := false
endif


ifndef ENABLE_SKB
export ENABLE_SKB := true
endif

ifndef ENABLE_HCI
export ENABLE_HCI := true
endif

# drv_opt used under chiling
# Company and Model
#

ifndef SONY_TUNER_DEMOD_NEW_VERSION
 	export SONY_TUNER_DEMOD_NEW_VERSION := true
endif

ifeq "$(DEMO_BOARD)" "true"
    # DEMO_BOARD
    DEFINES += -DDEMO_BOARD
    DEFINES += -DAPP_CFG_SUPPORT_OVERFLOW_CACHE
    DEFINES += -DCC_MEM_MID_DISABLE

    ifndef PCB
        export PCB := m3v1
        $(warning, NO PCB config, default is $PCB)
    endif

    export COMPANY                := mtk
    export MODEL                  := mt5885_sony_pad

    export NAND_PROFILE_4KB_256KB := false

    export BRDCST_IF := 5882DVBTC_VDRTuner_P_atdeu
    ifeq "$(findstring VDRTuner,$(BRDCST_IF))" "VDRTuner"
        export 3RD_PARTIES := LINUX
        export 3RD_PARTIES_CUST :=VDRBRDCST
        export CUST_TUNER := Si2157
    endif

else
    # Customer
	export TUNE_ACTUAL_FREQUENCY_SUPPORT := true

    DEFINES += -DCC_SIPADAN_LINUX
    DEFINES += -DWALKURE_PANEL_DETECTION
    ifeq "$(FHD)" "true"
    DEFINES += -DFORCE_FHD_PANEL
    endif
    ifeq "$(MANUAL_PANEL_SEL)" "true"
    DEFINES += -DCC_MANUAL_PANEL_SEL
    endif

    export INCLUDE_SONY_PRIV_FILES := true
    DEFINES += -DSONY_PRIV_FILES
    DEFINES += -DCC_Factory2K12
    DEFINES += -DCC_SONY_GAMMA

    # drv_opt used under chiling
    export COMPANY          := Sony
    export MODEL            := Unicorn_pa

    export NAND_PROFILE_4KB_256KB := false

    export BRDCST_IF := 5883_VDRDOMEDT2_VDRTuner_TUNERLESS_P_atdeu
    export 3RD_PARTIES := LINUX
    export 3RD_PARTIES_CUST := VDRBRDCST
    
    ifeq "$(SONY_TUNER_DEMOD_NEW_VERSION)" "true"
	    export CUST_DEMOD := CXD2856T
	    export CUST_TUNER := sonyascot3helene_new
    else
	    export CUST_DEMOD := CXD2854T
	    export CUST_TUNER := sonyascot3helene
    endif
    
    export CUST_VDRBRDCST_COMMON := Sony_FE

    # 3rd_party library
    3RD_PARTIES_MODEL        = Unicorn_pa
    export 3RD_PARTIES      := LINUX
    export 3RD_PARTIES_CUST := VDRBRDCST
    #export 3RD_PARTIES_MODEL += Common
    3RD_PARTIES_CUST        += Sony
    3RD_PARTIES_CUST_LOADER  = Sony
    export CC_CUSTOMER_LOADER = y
    export 3RD_PARTIES_CUST_LOADER
    export 3RD_PARTIES_CUST
    export 3RD_PARTIES_MODEL
endif

# enable image center for checking...
ifndef APP_IMG_CENTER_SUPPORT
export APP_IMG_CENTER_SUPPORT := false
endif

export MMS_SUPPORT

ifndef TOOL_CHAIN
export TOOL_CHAIN = 4.8.2
endif

export DIRECTFB_VERSION := 1.5.3

ifndef ENABLE_CA9
export ENABLE_CA9:=false
endif

ifeq "$(ENABLE_CA9)" "true"
	export ENABLE_CA9_NEON = false
else
	export ENABLE_CA9_NEON = true
endif

ifeq "$(ENABLE_CA9_NEON)_$(ENABLE_CA9)" "true_true"
$(error ENABLE_CA9_NEON conflict with ENABLE_CA9, please choose one of them)
endif

ifndef ENABLE_SMP_IC
export ENABLE_SMP_IC := true
endif

export MW_MODEL          := Unicorn_4K_EU

export LINUX_SOLUTION    := true
export KERNEL_VER        := linux-3.18
export VERSION           := t-apollo-mp-1501-1531-0-001-518-001-771-001-176
export ROOTFS_NAME       := 5886_free
export TARGET_IC         := mt5886
export REF_TARGET_IC     := mt5886
export ROOTFS_VER        := $(VERSION)
export KEY_FROM_DFB      := true
export AV_BYPASS         := 3
export UBOOT_VERSION     := 2011.12
export APP_IF            := mtal
export CUST_KERNEL_VER   := $(KERNEL_VER)
export CUST_LOADER_VER   := $(UBOOT_VERSION)
export OPENBOX           := true

ifndef FAST_BOOT
export FAST_BOOT := true
endif

ifndef 3RD_RO
export 3RD_RO := true
ifndef 3RD_RO_DBG
export 3RD_RO_DBG := false
endif
endif

ifndef IDLE_TV_AM_NOTIFY_KEY_TO_DTV
export IDLE_TV_AM_NOTIFY_KEY_TO_DTV := true
endif

export NET_LAZY_INIT := true
ifeq "$(RAMDISK)" "true"
export RAMDISK_ROOTFS := true
endif

ifndef SECURE_BOOT
export SECURE_BOOT    := y
endif

# secure boot, verify pkg key
ifndef USIG
export USIG := true
endif

export BUILD_PHASE    := PHASE1.75

ifndef DM_VERITY
export DM_VERITY      := true
endif

ifneq "$(KERNEL_VER)" "linux-3.0"
export USE_MKNFSBIMG_V3     := true
endif

ifeq "$(DM_VERITY)" "true"
export KERNEL_CONFIG_DIFF += dmverity
endif

ifeq "$(USB_ADB)" "true"
export KERNEL_CONFIG_DIFF += usb2_usb3_devicemode
endif

ifndef ENLARGE_3RD
export ENLARGE_3RD := false

ifeq "$(3RD_RO_DBG)" "true"
export ENLARGE_3RD := true
endif

endif

ifndef SUPPORT_TTY_USB
ifneq "$(DEMO_BOARD)" "true"
SUPPORT_TTY_USB :=true
endif
endif
export SUPPORT_TTY_USB

#
# FTRACE(MET/SYSTrace) Support
#
ifeq "$(ENABLE_MET_TOOL)" "true"
export FTRACE_SUPPORT := true
endif
ifeq "$(FTRACE_SUPPORT)" "true"
export KERNEL_CONFIG_DIFF += ftrace
endif

ifeq "$(SUPPORT_TTY_USB)" "true"
export KERNEL_CONFIG_DIFF += usbconsole
endif

ifneq "$(DEMO_BOARD)" "true"
ifndef EEPTOFLASH
export EEPTOFLASH := true
endif
endif

ifeq "$(NAND_TYPE)" "TOSHIBA_4G"
export TOSHIBA_4G := true
export OOB     := 0x1A
else ifeq "$(NAND_TYPE)" "TOSHIBA_2G"
export TOSHIBA_2G := true
export OOB     := 0x1A
else ifeq "$(NAND_TYPE)" "MACRONIX_4G"
export MACRONIX_4G := true
export OOB     := 0x10
else ifeq "$(NAND_TYPE)" "MACRONIX_2G"
export MACRONIX_2G := true
export OOB     := 0x10
else ifeq "$(NAND_TYPE)" "SPANSION_4G"
export SPANSION_4G := true
export OOB     := 0x1A
endif

ifeq "$(EEPTOFLASH)" "true"
  ifeq "$(JUST_TV)" "true"
    #JUST TV
    ifeq "$(NAND_WRITER)" "JTV2K128K"
      export NAND_WRITE_SCRIPT := nand_writer_2K_128K_256M_NOEEP_OAD.scr
      export NAND_WRITER_ENABLE=true
    endif
    ifeq "$(NAND_WRITER)" "JTV4K256K"
      export NAND_WRITE_SCRIPT := nand_writer_4K_256K_256M_NOEEP_OAD.scr
      export NAND_WRITER_ENABLE=true
    endif
    ifneq "$(NAND_WRITER)" ""
    ifneq "$(NAND_WRITER)" "JTV2K128K"
    ifneq "$(NAND_WRITER)" "JTV4K256K"
      $(error "Err: NAND_WRITER=$(NAND_WRITER) is not equal to JTV2K128K or JTV4K256K in JTV Model")
    endif
    endif
    endif
  else
  #Simple IPTV
    ifeq "$(NAND_WRITER)" "IPTV2K128K"
      export NAND_WRITE_SCRIPT := nand_writer_2K_128K_512M_NOEEP.scr
      export NAND_WRITER_ENABLE=true
    endif
    ifeq "$(NAND_WRITER)" "IPTV4K256K"
      export NAND_WRITE_SCRIPT := nand_writer_4K_256K_512M_NOEEP.scr
      export NAND_WRITER_ENABLE=true
    endif
    ifneq "$(NAND_WRITER)" ""
    ifneq "$(NAND_WRITER)" "IPTV4K256K"
    ifneq "$(NAND_WRITER)" "IPTV2K128K"
      $(error "Err: NAND_WRITER=$(NAND_WRITER) is not equal to IPTV2K128K or IPTV4K256K in IPTV Model")
    endif
    endif
    endif
  endif
else
export NAND_WRITE_SCRIPT := nand_writer_2K_128K_512M.scr
endif

ifndef BOOT_FROM_SDIO
export BOOT_FROM_SDIO := false
endif

export UBIFS          := true
ifndef MSDC_COMMON
export MSDC_COMMON      := true
endif

ifndef BOOT_TYPE
export BOOT_TYPE      := ROM2EMMC
endif

# ATTENTION:
# HS200
ifndef MSDC_ETT_HS200
export MSDC_ETT_HS200 := true
endif

ifeq "$(BOOT_TYPE)" "ROM2EMMC"
    export SYS_IMG_FS     := ext4
    ifeq "$(BOOT_FROM_SDIO)" "true"
        export KERNEL_CONFIG_DIFF += sdio
    else
        export KERNEL_CONFIG_DIFF += emmc
        ifeq "$(MSDC_COMMON)" "true"
        export KERNEL_CONFIG_DIFF += msdc_common
        endif
    endif
    export SDMMC_SUPPORT  := true
    export EXT_FS_SUPPORT := true
else
    export SYS_IMG_FS     := ubifs
    export UBIFS          := true
    export SDMMC_SUPPORT  := true
endif

#EXT2/EXT3/EXT4 SUPPORT
ifeq "$(EXT_FS_SUPPORT)" "true"
DEFINES += -DFM_EXT_FS_SUPPORT
endif

ifndef SDMMC_SUPPORT
export SDMMC_SUPPORT  := false
endif

ifeq "$(SDMMC_SUPPORT)" "true"
export KERNEL_CONFIG_DIFF += sdmmc
endif

ifndef VUDU_CMPB
export VUDU_CMPB      := false
endif

ifndef GLOBO_PLAY_SUPPORT
export GLOBO_PLAY_SUPPORT      := false
endif

ifndef COBALT_SUPPORT
export COBALT_SUPPORT := true
export COBALT_FEATURE_PRELOAD := true
endif

## dump Log to usb
#
ifndef LOG2USB
export LOG2USB := false
endif

#
#
# netflix Option: default on
#
ifndef NETFLIX_CMPB
    export NETFLIX_CMPB := true
endif
ifeq "$(NETFLIX_CMPB)" "true"
	export WEBP_SUPPORT := true
	export MNG_SUPPORT := true
	export SEAMLESS_SUPPORT := true
	export NETFLIX_APP_SUSPEND_SUPPORT := true
endif
ifndef NETFLIX_3D
    export NETFLIX_3D := true
endif

ifndef CUSTOM_SECURE_SUPPORT
export CUSTOM_SECURE_SUPPORT := true
endif

#
# Yahoo Widget Option: default off
#
ifndef YAHOO_WIDGET_SET
export YAHOO_WIDGET_SET ?= none
endif

ifndef SDM_SUPPORT
export SDM_SUPPORT := true
endif

ifeq "$(SUPPORT_DLNA_CTT_TEST)" "true"
DEFINES += -DAPP_SUPPORT_DLNA_CTT_TEST
endif

#
# Black Bar Support
#
ifndef BLACK_BAR_SUPPORT
export BLACK_BAR_SUPPORT := false
endif

#
# Wi-Fi Display (WFD) Option: default on
#

# add for build error , consultant : Hong Wang; Wen Xu; Liyong Zhang
ifndef RELEASE_3RD_LIB_WIFI
export RELEASE_3RD_LIB_WIFI := true
endif

ifeq "$(RELEASE_3RD_LIB_WIFI)" "true"

export CONFIG_NEW_WIFI_SUPPLICANT ?= true

#
# WIFI  default enalbe WIFI
#
ifndef WIFI_BT_FW_LOADER
export WIFI_BT_FW_LOADER:=7662
endif

export WIFI_DONGLE := MT7603U
export WIFI_WOW_SUPPORT :=true
ifndef WPA_CONFIG_RW
export WPA_CONFIG_RW := true
endif

#
# Built in Wifi module PID/VID
#
export BUILT_IN_WIFI_VID=148f
DEFINES += -DBUILT_IN_WIFI_VID=\"$(BUILT_IN_WIFI_VID)\"
export BUILT_IN_WIFI_PID=7601
DEFINES += -DBUILT_IN_WIFI_PID=\"$(BUILT_IN_WIFI_PID)\"

#
# Wifi Display
#
ifndef ENABLE_WIFI_DISPLAY
export ENABLE_WIFI_DISPLAY := true
endif


ifeq "$(RUN_ON_SOEM_BOARD)" "true"
#WoWLan
ifeq  "$(SIMPLE_IPTV)" "true"
ifneq "$(PCB)" "SCT"
ifndef SUPPORT_WAKE_UP_ON_WLAN
export SUPPORT_WAKE_UP_ON_WLAN := true
endif
endif
endif
endif

#
# Wifi Display cert, menu shall enable network setup
#
ifndef WIFI_DISPLAY_CERT
export WIFI_DISPLAY_CERT := false
endif

#Wifi Display volume control
export ENABLE_WFD_VOLUME_CONTROL := true


#
# High-bandwidth Digital Content Protection (HDCP) Option: default on with WFD, and must work with TRUSTZONE
#
ifeq "$(TRUSTZONE)" "true"
ifndef ENABLE_HDCP2
export ENABLE_HDCP2 := true
DEFINES += -DUSE_HDCPKEY_SONY_2K14
endif
endif
endif

#
# 3D Options
#
ifndef 3D_SUPPORT
export 3D_SUPPORT := false
endif

ifeq "$(3D_SUPPORT)" "true"
ifndef 3DSUPPORT_2D_PANEL
export 3DSUPPORT_2D_PANEL := false
endif

ifndef 3D_MM_DS_SUPPORT
export 3D_MM_DS_SUPPORT := true
endif
endif

# not the same with turnkey
ifndef 3D_PHOTO_ON_VDP
export 3D_PHOTO_ON_VDP := true
endif

export NTFS_WRITE_SUPPORT := false
export NTFS_FORMAT_SUPPORT := false

#
#Add for ac4 ipp
#
export AC4_IPP_CLASSIC_TZ_SUPPORT := true

#
#  Audio Description
#
ifndef SYS_AD_SUPPORT
export SYS_AD_SUPPORT := true
endif

#
# Menu memory shrink
#
ifndef MENU_DYNAMIC_LIFE_CYCLE_SUPPORT
export MENU_DYNAMIC_LIFE_CYCLE_SUPPORT := false
endif

# path customization for project_x/target/public/$(OS_TARGET)
export OS_TARGET            := linux-2.6.18

TARGET                      := linux_mak
BUILD_NAME                  := Unicorn_PA apollo-mp-1501-1531-0-001-518-001-771-001
MODEL_NAME                  := Unicorn_PA
CUSTOMER                    := SOEM_linux
CUSTOM                      := Sony/SOEM
CUST_MODEL                  := $(MODEL_NAME)
#SERIAL_NUMBER              := IDTV
THIS_ROOT                   := $(shell pwd)
export MODEL_DEF_PATH :=$(shell pwd)

# DirectFB
ifeq "$(JUST_TV)" "true"
export DIRECTFBRC           := directfbrc_1366_768_4444_and_960_540_8888
else
export DIRECTFBRC           := directfbrc_1366_768_8888_and_960_540_8888
endif

################################################################################################
#
# MTK Internal Version
#
ifeq "$(VERSION)" "DTV_X_IDTV0801"
    MTK_VERSION := $(VERSION)
else
    MTK_VERSION := $(word 2, $(subst DTV_X_IDTV0801_,DTV_X_IDTV0801_ , $(VERSION)))
    ifeq "$(MTK_VERSION)" ""
    MTK_VERSION := $(word 2, $(subst IDTV0801_,IDTV0801_ , $(VERSION)))
    ifeq "$(MTK_VERSION)" ""
        MTK_VERSION := $(VERSION)
    endif
    endif
endif
DEFINES += -DMTK_VERSION=\"$(MTK_VERSION)\"

#
# Customer Version
#
CUSTOMER_VERSION_BASIC = vx.xxx
export CUSTOMER_VERSION = $(CUSTOMER_VERSION_BASIC)

#
# Extended Version for specail purpose
#
ifneq "$(EXT_VER)" ""
export CUSTOMER_VERSION = $(CUSTOMER_VERSION_BASIC)"_"$(EXT_VER)
endif
DEFINES += -DCUSTOMER_VERSION=\"$(CUSTOMER_VERSION)\"

#
# Model type setting
#
DEFINES += -DSIPADAN_PADIP

#
# Customer Library Version
#
#EMCS_LIB_VER=1.02
#DEFINES += -DTHIRD_PARTY_EMCS_LIB_VERION=\"$(EMCS_LIB_VER)\"

#
# Serial Number
#
export SERIAL_NUMBER := $(CUSTOMER_VERSION)

#
# USB/NDD upgrade version
#
export USB_UPG_VERSION := $(VERSION)
export NDD_UPG_VERSION := $(CUSTOMER_VERSION)

#
# IPTV system version
#
export IPTV_VERSION := vx.xxx

#
# Add local compile defines
#
DEFINES += -DMODEL_NAME=\"$(MODEL_NAME)\"
DEFINES += -DCUST_MODEL=\"$(CUST_MODEL)\"
DEFINES += -DSERIAL_NUMBER=\"$(SERIAL_NUMBER)\"
DEFINES += -DUSB_UPG_VERSION=\"$(USB_UPG_VERSION)\"
DEFINES += -DNDD_UPG_VERSION=\"$(NDD_UPG_VERSION)\"
DEFINES += -DIPTV_VERSION=\"$(IPTV_VERSION)\"

#
# MID
#
ifeq "$(MID_DISABLE)" "true"
DEFINES += -DCC_MEM_MID_DISABLE
endif

#
# IR Configuration
#
ifeq "$(MTK_IR)" "true"
export MTK_IR_ENABLE=true
endif


#
# Flash Panel
#
#ifneq "$(DEMO_BOARD)" "true"
#  ifeq "$(FLASH_PANEL_DISABLE)" "true"
#  export FLASH_PANEL_TABLE=false
#  endif
#else
#  export FLASH_PANEL_TABLE=false
#endif

#
# Self Diagnostic
#
ifneq "$(DEMO_BOARD)" "true"
  ifeq "$(SELF_DIAG_OFF)" "true"
  export SELF_DIAG_DEFAULT_OFF=true
  endif
else
  export SELF_DIAG_DEFAULT_OFF=true
endif

#
# Time Measurement
#

ifeq "$(TIME_MEASURE)" "true"
export TIME_MEASURE=true
endif

#
# SVL packing
#
ifeq "$(PACK_SVL)" "true"
export PACK_SVL=true
endif

#
# Options for CUST_RLS
#
ifeq "$(CUST_RLS)" "true"
export NAND_WRITER_ENABLE=true
export CUST_RLS=true
export PACK_ALL=true
#export SELF_DIAG_DEFAULT_ON=true
export SELF_DIAG_ON=true
endif

#
# The build option to define disable log in default or not
#
ifeq "$(NO_LOG)" "true"
DEFINES += -DAPP_NO_LOG
endif

#
# Same as CUST_RLS=true but no Nand writer.
# This option is used for auto release.
#
ifeq "$(CUST_RLS_INTERNAL)" "true"
export PACK_ALL=true
#export SELF_DIAG_ON=true
endif

ifeq "$(NAND_WRITER)" "true"
export NAND_WRITER_ENABLE=true
endif

#
# 3rd party library
#
ifneq "$(DEMO_BOARD)" "true"
# define later
#export 3RD_PARTIES :=
endif

#
# Force Upgrade
#
ifneq "$(DEMO_BOARD)" "true"
  #ifeq "$(FORCE_UPGRADE)" "true"
  export FORCE_UPGRADE=true
  #endif
else
  export FORCE_UPGRADE=true
endif

#
# Start-up Logo Sound (removed from FY12 models)
#
ifndef BOOT_UP_LOGO_SOUND
export BOOT_UP_LOGO_SOUND := false
endif

ifeq "$(BOOT_TYPE)" "ROM2NAND"
ifeq "$(RUN_ON_SOEM_BOARD)" "true"
#WoWLan
export ONE_IMG_FOR_MULTI_NAND :=true
endif
endif

#include ../common/$(BRAND)/common.mak
#include ../common/$(BRAND)/ubi_fs.mak

ifneq "$(NAND_PROFILE_4KB_256KB)" "true"
export UBI_MAX_LOG_BLK_EARSE_CNT_BASIC :=$(UBI_MAX_LOG_BLK_EARSE_CNT_BASIC_2K_128K)
export UBI_MAX_LOG_BLK_EARSE_CNT_PERM  :=$(UBI_MAX_LOG_BLK_EARSE_CNT_PERM_2K_128K)
export UBI_MAX_LOG_BLK_EARSE_CNT_3RD_RO :=$(UBI_MAX_LOG_BLK_EARSE_CNT_3RD_RO_2K_128K)
export UBI_MAX_LOG_BLK_EARSE_CNT_3RD_RW :=$(UBI_MAX_LOG_BLK_EARSE_CNT_3RD_RW_2K_128K)
else
export UBI_MAX_LOG_BLK_EARSE_CNT_BASIC :=$(UBI_MAX_LOG_BLK_EARSE_CNT_BASIC_4K_256K)
export UBI_MAX_LOG_BLK_EARSE_CNT_PERM  :=$(UBI_MAX_LOG_BLK_EARSE_CNT_PERM_4K_256K)
export UBI_MAX_LOG_BLK_EARSE_CNT_3RD_RO :=$(UBI_MAX_LOG_BLK_EARSE_CNT_3RD_RO_4K_256K)
export UBI_MAX_LOG_BLK_EARSE_CNT_3RD_RW :=$(UBI_MAX_LOG_BLK_EARSE_CNT_3RD_RW_4K_256K)
endif

#########################################################################################################


ifeq "$(APP_IF)" "mtal"
export MTAL_SUPPORT   := true
endif

ifndef OPTIMIZE_LVL
ifeq "$(BUILD_CFG)" "debug"
export OPTIMIZE_LVL = -O0
else
export OPTIMIZE_LVL = -O2
endif
endif

export THUMB = n

# Add local tuner driver setting.
#
ifndef BRDCST_IF_BUILD_ALL
export BRDCST_IF_BUILD_ALL =false
endif

#
# LOADER_USB_UPGRADE
#
ifndef LOADER_USB_UPGRADE
export LOADER_USB_UPGRADE := true
endif

#
# MTD Encryption
#
ifndef MTD_ENCRYPT_SUPPORT
export MTD_ENCRYPT_SUPPORT := true
endif

#
# Flash adspbin
# ADSPBIN_ROOT: adspbin root directory
# please config it correctly if FLASH_ADSP_BIN is true
#
ifndef FLASH_ADSP_BIN
export FLASH_ADSP_BIN      := true
export ADSPBIN_ROOT        := adspbin8290
endif

# Put basic into rootfs
#
ifndef BASIC_IN_ROOTFS
export BASIC_IN_ROOTFS := false
endif

#
# config FAST_INIT_TYPE
# 1. APP: suspend in APP
# 2. MW: suspend in MW
#
ifeq "$(FAST_INIT_SUPPORT)" "true"
    #export UBI_3RD_CFG := ubi_3rd_fast.cfg # cyj.todo
    ifndef FAST_INIT_TYPE
    export FAST_INIT_TYPE := MW
    endif
endif

#
# Animation Support
#
ifndef ANIMATION_SUPPORT
export ANIMATION_SUPPORT := true
endif

#
# Capture Logo
#
ifndef CAPTURE_LOGO_SUPPORT
export CAPTURE_LOGO_SUPPORT := false
endif

#
# ISO Support
#
ifndef SYS_ISO_SUPPORT
    export SYS_ISO_SUPPORT := true
endif

ifeq "$(SYS_ISO_SUPPORT)" "true"
    export KERNEL_CONFIG_DIFF += iso
endif

#
# MHL Support Options
#
ifndef MHL_SUPPORT
export MHL_SUPPORT := false
endif

#
# pre select channel to improve bootup time.
#
ifndef PRE_SELECT_CH
export PRE_SELECT_CH := true
endif

#
# Fastboot Support
#
ifndef SUSPEND_TO_DRAM
export SUSPEND_TO_DRAM := true
endif

ifeq "$(SUSPEND_TO_DRAM)" "true"
    export KERNEL_CONFIG_DIFF += stram
    ifndef SUSPEND_TO_DRAM_DEBUG
        export SUSPEND_TO_DRAM_DEBUG := false
    endif
    ifndef TUNER_RUNTIME_PM
        export TUNER_RUNTIME_PM := false
    endif
endif

#
# AV Bypass Configuration
#
# 1: Disable AV Bypass
# 2: Enable Monitor Bypass only
# 3: Enable TV & Monitor Bypass concurrently
# 4: Enable TV Bypass only
#
ifndef AV_BYPASS
export AV_BYPASS := 3
endif

ifndef SUPPORT_PIP
export SUPPORT_PIP = false
endif

#
# Multimedia Options (OPTIONS: none / basic / full)
#   "MMP_SUPPORT=none"  : No MMP
#   "MMP_SUPPORT=basic" : MP3 + JPEG only
#   "MMP_SUPPORT=full"  : MP3 + JPEG + Video Playback
#
export MMP_SUPPORT := full

#
# Time-Shift & PVR Options
#
ifndef ENABLE_DTV_TIME_SHIFT
    export ENABLE_DTV_TIME_SHIFT := flase
endif
ifndef ENABLE_DTV_PVR
    export ENABLE_DTV_PVR := true
endif

#
# Svl partial update feature
#
ifndef ENABLE_SVL_PARTIAL_UPDATE
    export ENABLE_SVL_PARTIAL_UPDATE := true
endif
##################################################################################
# AV record for ATV and CVBS record ( may extend to support other input sources ).
# NOTE:
#    If Enable AV timeshift or AV PVR, please confirm the CVBS is separated from
# Combi source in sys_drv_custom.c !
##################################################################################
ifndef ENABLE_AV_TIME_SHIFT
    export ENABLE_AV_TIME_SHIFT := false
endif
ifndef ENABLE_AV_PVR
    export ENABLE_AV_PVR := false
endif

ifndef ENABLE_SCHED_PVR
    ifeq "$(ENABLE_DTV_PVR)" "true"
        export ENABLE_SCHED_PVR := true
    else
        ifeq "$(ENABLE_AV_PVR)" "true"
            export ENABLE_SCHED_PVR := true
        else
            export ENABLE_SCHED_PVR := false
        endif
    endif
endif

##### Prepare internal variable (Do not modify)
ifeq "$(ENABLE_DTV_TIME_SHIFT)" "true"
    export TSHFT_CORE_LIB := true
else
    ifeq "$(ENABLE_DTV_PVR)" "true"
        export TSHFT_CORE_LIB := true
    else
        export TSHFT_CORE_LIB := false
    endif
endif

##################################################################################
# AV record for ATV and CVBS record ( may extend to support other input sources ).
# NOTE:
#    If Enable AV timeshift or AV PVR, please confirm the CVBS is separated from
# Combi source in sys_drv_custom.c !
##################################################################################
ifeq "$(ENABLE_AV_TIME_SHIFT)" "true"
    AV_RECORD_LIB := true
else
    ifeq "$(ENABLE_AV_PVR)" "true"
        AV_RECORD_LIB := true
    else
        AV_RECORD_LIB := false
    endif
endif
export AV_RECORD_LIB

export ENABLE_LIBC_O2 = true

# Network support
ifndef INET_SUPPORT
export INET_SUPPORT := true
endif

#
# Firmware Upgrade
#
# none : No Firmware Upgrade
# mtk  : Turkey USB Upgrade + Network Upgrade
# uli  : UpdateLogic
# ond  : only support sony ond ,not support NDD&OAD for JUST_TV model
#

ifneq "$(INET_SUPPORT)" "true"
    export FW_UPG_SUPPORT := ond
else
    ifndef SMB_SUPPORT
    export SMB_SUPPORT := false
    endif
    export FW_UPG_SUPPORT := mtk
endif


#
# Hotkey wakeup
#
ifeq "$(RELEASE_3RD_POLICY)" "SONY_IPTV"
ifndef HOTKEY_WAKEUP_SUPPORT
    export HOTKEY_WAKEUP_SUPPORT := true
    export SONY_NETFLIX_KEY_SUPPORT :=false
endif
endif

# for TVAP to 3rd RPC
ifeq "$(RELEASE_3RD_POLICY)" "SONY_IPTV"
export TVAP_RPCAPI_3RD_SUPPORT := true
endif

#
# DivX DRM Configuration
#
# 1: HT 2.2,    SDK 4.0 patch 3.02
# 2: HT 3.0,    SDK 5.1
# 3: HD,        SDK 5.1
# 4: HD 1.2,    SDK 6.0
# 5: HD Plus,   SDK 6.0
# 6: HD Plus 1.1,   SDK 6.0
# 7: HD 1.3,        SDK 6.1 addendum
# 8: HT 3.1,        SDK 6.1 addendum
#
#
ifndef DIVX_DRM
export DIVX_DRM := 4
endif

ifeq ($(DIVX_DRM), 1)
    DEFINES += -DDIVX_DRM_40
else ifeq ($(DIVX_DRM), 2)
    DEFINES += -DDIVX_DRM_51
else ifeq ($(DIVX_DRM), 3)
    DEFINES += -DDIVX_DRM_51
else ifeq ($(DIVX_DRM), 4)
    DEFINES += -DDIVX_DRM_60
else ifeq ($(DIVX_DRM), 5)
    DEFINES += -DDIVX_DRM_60
else ifeq ($(DIVX_DRM), 6)
    DEFINES += -DDIVX_DRM_61
else ifeq ($(DIVX_DRM), 7)
    DEFINES += -DDIVX_DRM_61
else ifeq ($(DIVX_DRM), 8)
    DEFINES += -DDIVX_DRM_61
endif

#
# Add local compile defines
#

#
# Loader Maximum Size
# Load Size Partition = 2MB
#
export LOADER_MAX_SIZE=2097152

#
# Audio decoder
#
export AUD_SUPPORT_3_DECODER :=1
export AUD_APROC_RENDER := true

#
# Global chip set setting.
#
export GLOBAL_CHIP_SET = mt5396_512mb_pad

ifndef FBM_MEM_CFG
export FBM_MEM_CFG = 5363_64MBx2
endif

export LINUX_SOLUTION = true

export MODEL_NAME BUILD_NAME SERIAL_NUMBER CUSTOMER VERSION TARGET_IC DEFINES

export DISCARD_SUPPORT_PCMCIA := true

################################################################################################
#
# IPTV Specific
#

ifeq "$(INET_SUPPORT)" "true"
export USE_SMART_FILE := true
ifndef WAKE_ON_LAN
export WAKE_ON_LAN := false
endif

ifndef MTKSTREAM_SUPPORT
export MTKSTREAM_SUPPORT := true
endif

endif

#
# Generic DIAL server
#
ifeq "$(INET_SUPPORT)" "true"
export DIAL_SUPPORT := true
endif

#
# IPv6
#
ifndef IPV6_SUPPORT
export IPV6_SUPPORT := false
endif

#
# Flingo ACR Option: default on
#
ifndef SUPPORT_VSS_FLINGO
export SUPPORT_VSS_FLINGO := false
endif

#
# Flash Player 10 Option: default off
#
ifndef ENABLE_FP10
export ENABLE_FP10 := false
endif

# Loader logo
#
ifndef LOADER_LOGO_SUPPORT
export LOADER_LOGO_SUPPORT := false
endif

#
# driver cli move from dtv_driver.ko to driver_cli.ko
#
ifndef STANDALONE_CLI_MODULE
export STANDALONE_CLI_MODULE := true
endif

#
# GFX MMU for DFB. If enable this define, DFB will share system memory when DFB memory is not enough
#
ifndef GFX_MMU_SUPPORT
export GFX_MMU_SUPPORT := true
endif

###DDP support
ifndef SPDIF_DDP_SUPPORT
export SPDIF_DDP_SUPPORT := true
endif

#
# Basic partition
#

#
# 3RD Partition
#
export DELAY_MOUNT_3RD = true

#
# 3RD_RW Partition
#
export PUT_3RD_RW_FILE_IMAGE_TO_BASIC=true

#
# Skype Option: default off
#
ifndef V4L_SUPPORT
export V4L_SUPPORT := false
endif

#
# Bluetooth Option: default off
#
ifndef BLUETOOTH
export BLUETOOTH := false
endif
ifeq "$(BLUETOOTH)" "true"
export 4_AUDIO_DECODER := true
endif

ifndef BIVL_VERSION
export BIVL_VERSION = 1.6.2
endif

# Photo Share
ifndef PHOTO_SHARE_SUPPORT
export PHOTO_SHARE_SUPPORT := true
endif

# Play Anywhere
ifndef PLAY_ANYWHERE_SUPPORT
export PLAY_ANYWHERE_SUPPORT := false
endif

ifeq "$(PLAY_ANYWHERE_SUPPORT)" "true"
ifndef NDB_SUPPORT
    export NDB_SUPPORT = true
endif
endif

ifeq "$(CUSTOM_SECURE_SUPPORT)" "true"
export LINK_LIBS_inet       += -L$(THIS_ROOT)/../../../linux_mts/mtk_util/library/gnuarm-4.8.2_neon_ca9/securestorage/lib/ -lcustom_security -lsecurestorage
endif

################################################################################################
#
# EU/PAD Specific
#

# Subtitle
ifndef SYS_SUBTITLE_SUPPORT
export SYS_SUBTITLE_SUPPORT = true
endif

# CI Engine
ifndef SYS_CI_SUPPORT
export SYS_CI_SUPPORT := false
endif

ifeq "$(SYS_CI_SUPPORT)" "true"
    export CI_ENGINE := oceanblue_ci
    ifndef CI_PLUS_SUPPORT
    export CI_PLUS_SUPPORT := true
    endif
    ifndef CI_PLUS_V13_SUPPORT
    export CI_PLUS_V13_SUPPORT := true
    endif
    ifeq "$(CI_PLUS_SUPPORT)" "true"
        ifndef CIPLUS_PRODUCT_KEY
        export CIPLUS_PRODUCT_KEY := true
        endif
        ifndef CANAL_READY_PRODUCT_KEY
        #Enable this definition when MP
        export CANAL_READY_PRODUCT_KEY := false
        endif
        ifndef DEMO_FAKE_IC
        export DEMO_FAKE_IC := false
        endif
        ifndef COMPATIBLE_CAM_V12
            export COMPATIBLE_CAM_V12 := false
        endif
    endif
    ifndef EXTERNAL_CI_SUPPORT
    # MT5396 use internal CI controller
    export EXTERNAL_CI_SUPPORT := false
    endif

    # Downgrade CC version for CI+ 1.2 CAM
    #ifeq "$(CI_PLUS_V13_RES_VER_V12)" "true"
    DEFINES += -DCI_PLUS_V13_RES_VER_V12
    #endif
endif

# MS10 (EU/PAD only)
ifndef SYS_MS10_SUPPORT
export SYS_MS10_SUPPORT = true
endif

# EWS_PA support
 ifndef EWS_PA_SUPPORT
 export EWS_PA_SUPPORT := true
 endif
# Disable Indonesia EWS
#export EWS_PA_SUPPORT := false

# MHEG5 support
ifndef SYS_MHEG5_SUPPORT
export SYS_MHEG5_SUPPORT := false
endif

# FreeviewHD support
ifeq "$(SYS_MHEG5_SUPPORT)" "true"
export SYS_UK_FREEVIEWHD_SUPPORT := false
export SYS_AUS_FREEVIEWHD_SUPPORT := false
export SYS_NZ_FREEVIEWHD_SUPPORT := true
else
export SYS_UK_FREEVIEWHD_SUPPORT := false
export SYS_AUS_FREEVIEWHD_SUPPORT := false
export SYS_NZ_FREEVIEWHD_SUPPORT := false
endif

ifeq "$(SYS_UK_FREEVIEWHD_SUPPORT)" "true"
    # MHEG5 support
    export SYS_MHEG5_SUPPORT := true

    # MHEG5 UK support
    export SYS_MHEG5_UK_SUPPORT := true

    # MHEG5 HD
    export MHEG5_HD_SUPPORT := true

    # MHEG5 Interaction Channel
    export MHEG5_IC_SUPPORT := true

    # MHEG5 NVM
    export MHEG5_NVM_SUPPORT := true
endif

ifeq "$(SYS_AUS_FREEVIEWHD_SUPPORT)" "true"
    # MHEG5 support
    export SYS_MHEG5_SUPPORT := true

    # MHEG5 AUS support
    export SYS_MHEG5_AUS_SUPPORT := true

    # MHEG5 HD
    export MHEG5_HD_SUPPORT := true

    # MHEG5 Interaction Channel
    export MHEG5_IC_SUPPORT := true

    # MHEG5 NVM
    export MHEG5_NVM_SUPPORT := true
endif

ifeq "$(SYS_NZ_FREEVIEWHD_SUPPORT)" "true"
    # MHEG5 support
    export SYS_MHEG5_SUPPORT := true

    # MHEG5 NZ support
    export SYS_MHEG5_NZ_SUPPORT := true

    # MHEG5 HD
    export MHEG5_HD_SUPPORT := true

    # MHEG5 Interaction Channel
    export MHEG5_IC_SUPPORT := true

    # MHEG5 NVM
    export MHEG5_NVM_SUPPORT := true
endif

#MHEG5 and Subtitle coexistence
ifeq "$(SYS_MHEG5_SUPPORT)" "true"
    ifndef SYS_MHEG5_COEXIST_WITH_SUBTITLE
        ifeq "$(MHEG5_IC_SUPPORT)" "true"
            export SYS_MHEG5_COEXIST_WITH_SUBTITLE := true
        else
            export SYS_MHEG5_COEXIST_WITH_SUBTITLE := false
        endif
    else
        ifeq "$(MHEG5_IC_SUPPORT)" "true"
            ifeq "$(SYS_MHEG5_COEXIST_WITH_SUBTITLE)" "false"
            $(error "MHEG5_IC_SUPPORT is true, SYS_MHEG5_COEXIST_WITH_SUBTITLE must be true")
            endif
        endif
    endif
else
    ifndef SYS_MHEG5_COEXIST_WITH_SUBTITLE
        export SYS_MHEG5_COEXIST_WITH_SUBTITLE := false
    else
        ifeq "$(SYS_MHEG5_COEXIST_WITH_SUBTITLE)" "true"
            $(error "SYS_MHEG5_SUPPORT is false, SYS_MHEG5_COEXIST_WITH_SUBTITLE must be false")
        endif
    endif
endif

#
# EDB Support
#
ifneq "$(EDB_SUPPORT)" "false"
DEFINES += -DEDB_SUPPORT
export EDB_SUPPORT := true
endif
$(waning EDB_SUPPORT=$(EDB_SUPPORT))

# MHP
ifndef SYS_MHP_SUPPORT
export SYS_MHP_SUPPORT = false
endif

ifeq "$(SYS_MHP_SUPPORT)" "true"
    export DASH_SUPPORT := true
    export MTKSTREAM_SUPPORT := true
    export CMPB_DASH_SUPPORT := true
    export BACKGROUND_PSI_SI_MONITOR := true
endif

#
#Browser Background Support
#
ifndef BROWSER_BACKGROUND_SUPPORT
    export BROWSER_BACKGROUND_SUPPORT := true
endif

#HBBTV Support
ifndef HBBTV_SUPPORT
    ifeq  "$(SIMPLE_IPTV)" "true"
    export HBBTV_SUPPORT := true
    endif
endif

ifeq "$(HBBTV_SUPPORT)" "true"
    ifndef HBBTV_SOLUTION
        export HBBTV_SOLUTION := opera
    endif
    ifeq "$(BROWSER_BACKGROUND_SUPPORT)" "true"
        export HBBTV_AM_SUPPORT := true
    else
        export HBBTV_AM_SUPPORT := false
    endif
    ifndef DEMO_FAKE_HBBTV_IC
        export DEMO_FAKE_HBBTV_IC := false
    endif
    ifndef CMPB_DASH_SUPPORT
        export CMPB_DASH_SUPPORT := true
    endif
    ifndef SEAMLESS_SUPPORT
        export SEAMLESS_SUPPORT := true
    endif
    ifndef DASH_SUPPORT
        export DASH_SUPPORT := true
    endif
    ifndef MTKSTREAM_SUPPORT
        export MTKSTREAM_SUPPORT := true
    endif
	ifndef MTK_DRM_SUPPORT
	    export MTK_DRM_SUPPORT := true
    endif
    ifneq "$(HBBTV_SOLUTION)" "opera"
    export SYS_DSMCC_SUPPORT := true
    endif
    # Don't enable it because PAD doesn't support PVR.
    # export BACKGROUND_PSI_SI_MONITOR := true
ifndef ZONEINFO_SUPPORT
export ZONEINFO_SUPPORT := true
export ZONEINFO_LOCALTIME_SUPPORT := true
export ZONEINFO_DEFAULT := "Africa/Djibouti"
endif
endif

# OAD
ifndef SYS_OAD_SUPPORT
export SYS_OAD_SUPPORT = true
endif

# BGM
ifndef SYS_BGM_SUPPORT
export SYS_BGM_SUPPORT = true
endif

# FLIP/MIRROR support
# default is false
ifndef SYS_FLIP_SUPPORT
export SYS_FLIP_SUPPORT = false
endif

ifndef SYS_MIRROR_SUPPORT
export SYS_MIRROR_SUPPORT = false
endif

# DRM
ifeq "$(MTK_DRM_SUPPORT)" "true"
	ifndef ENABLE_INTERTRUST_SUPPORT
	    export ENABLE_INTERTRUST_SUPPORT := false
	endif
	ifndef ENABLE_PLAYREADY_SUPPORT
	    export ENABLE_PLAYREADY_SUPPORT := true
	endif
    ifndef ENABLE_NAUTILUS_SUPPORT
        export ENABLE_NAUTILUS_SUPPORT := true
    endif
endif

ifeq "$(ENABLE_NAUTILUS_SUPPORT)" "true"
    ifndef ENABLE_HCI
        export ENABLE_HCI := true
    endif
    ifndef ENABLE_NAUTILUS_ATK
        export ENABLE_NAUTILUS_ATK := false
    endif
    ifndef ENABLE_NAUTILUS_NEW_KEYFORMAT
        export ENABLE_NAUTILUS_NEW_KEYFORMAT := false
    endif
endif

#
# Enable ICE debug for default
#
ifeq "$(ENABLE_HDMI_JTAG)" "true"
DEFINES += -DCC_ENABLE_HDMI_JTAG
endif

#
# Disable MET TOOL(just could run on CA9 IC) for default
#
ifndef ENABLE_MET_TOOL
export ENABLE_MET_TOOL := false
endif

#
# Dolby tech. license
#
# NON = no Dolby
# MS12 = MS12 profile MS11 (DD transcoder)
# MS12B = MS12 profile B (DDP transcoder)
# MS10 = MS10 (DDC + DDT)
# DCV = Dolby Digital Plus (with converter)
# DD = Dolby Digital
# DP = Dolby Pulse (with DDENC)
# DDCO = DDCO (with HE-AAC)
# DCV+DDCO = DCV + DDCO
# DD+DDCO = DD + DDCO
# DD+DP = DD + DP
ifndef AUD_DOLBY_SUPPORT
ifeq  "$(SIMPLE_IPTV)" "true"
export AUD_DOLBY_SUPPORT = MS12B
else
export AUD_DOLBY_SUPPORT = MS12B
endif
endif

ifeq "$(AUD_DOLBY_SUPPORT)" "MS12"
    export 3RD_PARTIES_CUST +=DOLBY
else ifeq "$(AUD_DOLBY_SUPPORT)" "MS12B"
    export 3RD_PARTIES_CUST +=DOLBY
	ifndef AUD_CPUDEC_SUPPORT
        export AUD_CPUDEC_SUPPORT = true
    endif
    export AUD_DOLBY_SUPPORT_MS12 = true
    export AUD_DOLBY_SUPPORT_AC4 = true
endif

#
# CFG Combine
#
export COMBINED_BUILD_CFG := true

#
# SW Keyboard
#
ifndef SIP_SWKB_SUPPORT
export SIP_SWKB_SUPPORT := true
endif

#
# OAD version check
#
# CUST_OAD_OUI         should accurate 3 bytes, need prefix 0 when digit is not enough
# CUST_OAD_HW_MODEL    should accurate 2 bytes, need prefix 0 when digit is not enough
# CUST_OAD_HW_VERSION  should accurate 2 bytes, need prefix 0 when digit is not enough
# CUST_OAD_SW_MODEL    should accurate 2 bytes, need prefix 0 when digit is not enough
# CUST_OAD_SW_VERSION  should accurate 2 bytes, need prefix 0 when digit is not enough
export CUST_OAD_OUI := 0x080046
DEFINES += -DCUST_OAD_OUI=$(CUST_OAD_OUI)
#-------------------------------------------------------------------------------------
# Default HW/SW Model/Version for auto TS generation
export CUST_OAD_HW_MODEL := 0x0270
export CUST_OAD_HW_VERSION := 0x0009
export CUST_OAD_SW_MODEL := 0x7009
export CUST_OAD_SW_VERSION := 0x2000

DEFINES += -DCUST_OAD_HW_MODEL=$(CUST_OAD_HW_MODEL)
DEFINES += -DCUST_OAD_HW_VERSION=$(CUST_OAD_HW_VERSION)
DEFINES += -DCUST_OAD_SW_MODEL=$(CUST_OAD_SW_MODEL)
DEFINES += -DCUST_OAD_SW_VERSION=$(CUST_OAD_SW_VERSION)
#-------------------------------------------------------------------------------------

#-------------------------------------------------------------------------------------
# EU HW/SW Model/Version
export CUST_EU_OAD_HW_MODEL := 0x0270
export CUST_EU_OAD_HW_VERSION := 0x0009
export CUST_EU_OAD_SW_MODEL := 0x7009
export CUST_EU_OAD_SW_VERSION := 0x2000

DEFINES += -DCUST_EU_OAD_HW_MODEL=$(CUST_EU_OAD_HW_MODEL)
DEFINES += -DCUST_EU_OAD_HW_VERSION=$(CUST_EU_OAD_HW_VERSION)
DEFINES += -DCUST_EU_OAD_SW_MODEL=$(CUST_EU_OAD_SW_MODEL)
DEFINES += -DCUST_EU_OAD_SW_VERSION=$(CUST_EU_OAD_SW_VERSION)
#-------------------------------------------------------------------------------------

#-------------------------------------------------------------------------------------
# PAD HW/Sw Model/Version
export CUST_PAD_OAD_HW_MODEL := 0x0270
export CUST_PAD_OAD_HW_VERSION := 0x000b
export CUST_PAD_OAD_SW_MODEL := 0x700b
export CUST_PAD_OAD_SW_VERSION := 0x2000

DEFINES += -DCUST_PAD_OAD_HW_MODEL=$(CUST_PAD_OAD_HW_MODEL)
DEFINES += -DCUST_PAD_OAD_HW_VERSION=$(CUST_PAD_OAD_HW_VERSION)
DEFINES += -DCUST_PAD_OAD_SW_MODEL=$(CUST_PAD_OAD_SW_MODEL)
DEFINES += -DCUST_PAD_OAD_SW_VERSION=$(CUST_PAD_OAD_SW_VERSION)
#-------------------------------------------------------------------------------------

#
#
# USB upgrade version
#
export USB_UPG_LOADER_VER := $(CUSTOMER_VERSION)
export USB_UPG_FW_VER := $(CUSTOMER_VERSION)
export USB_UPG_PANEL_VER := PADPN0.0060.0000
export USB_UPG_PQ_VER := PQ1.3003
export USB_UPG_AQ_VER := AQ1.3004
export USB_UPG_EDID_VER := 1.00
export USB_UPG_SERV_VER := 1.00
export USB_UPG_NVRM_VER := TD1.000

ifndef FORCE_UPGRADE
export FORCE_UPGRADE := true
endif

ifeq "$(FORCE_UPGRADE)" "true"
export FORCE_UPGRADE_VERSION := 99999999
endif

#
# UBIFS partition definition (overwrite rootfs/Makefile)
#
ifeq "$(SYS_IMG_FS)" "ext4"
    export MAIN_PART_ID = 14
    export 3RD_PART_ID  = 15
    export PERM_PART_ID = 6
    ifeq "$(3RD_RO)" "true"
        export 3RD_RO_PART_ID = 17
	endif
	export UPGR_PART_ID  = 16
    export UPGR_PART_NAME = upgrade
    export UPGR_PART_VOL_NAME = upgrade
    export SRC_MOUNT_UPGR_SH    = mount_upgr.sh
    export SRC_UNMOUNT_UPGR_SH   = unmount_upgr.sh
else ifeq "$(UBIFS)" "true"
    export MAIN_PART_ID = 8
    export 3RD_PART_ID  = 9
    export PERM_PART_ID = 10
    ifeq "$(3RD_RO)" "true"
        export 3RD_RO_PART_ID = 12
	endif
endif

#
# CUSTOM RPC dir
#
export MTKTVAPI_SUPPORT := false

ifndef CUSTOM_RPC_DIR
export CUSTOM_RPC_DIR := custom/dev
endif

# enable for SQA Memory consumption/performance test
# default is disable
#
# System Memory Check
#
ifndef SYS_MEM_CHK
export SYS_MEM_CHK := false
endif
#
# System Performance Check
#
ifndef SYS_PERFORMANCE_CHK
export SYS_PERFORMANCE_CHK := false
endif

ifeq "$(SYS_PERFORMANCE_CHK)" "true"
export TMS_SUPPORT := true
endif

ifeq "$(BUILD_CFG)" "debug"
ENABLE_PRINT_MEM_MAP = true
endif

ifndef ENABLE_PRINT_MEM_MAP
ENABLE_PRINT_MEM_MAP = false
endif

#
# SOEM factory ch info
#
ifndef DEFAULT_FAC_CHANNEL
export DEFAULT_FAC_CHANNEL := true
endif

export ENABLE_PRINT_MEM_MAP

#export KERNEL_CONFIG_DIFF += fast_squashfs

#
# Include customer mak file
#

#
# Flash analysis
#
#-include ../common/$(BRAND)/flash_analysis.mak
